@@ -97,6 +97,7 @@ DO_SAVE = True
 AUTODISCONNECT = True
 PAR_CLEANUP = False
 PAR_OPTION = ''
+PAR_MULTICORE = False
 NO_DUPES = False
 
 QUEUECOMPLETE = None #stores the nice name of the action
@@ -120,6 +121,7 @@ USERNAME_NEWZBIN = None
 PASSWORD_NEWZBIN = None
 
 API_KEY = None
+NO_API_KEY = None
 
 CACHE_DIR = None
 NZB_BACKUP_DIR = None
@@ -312,7 +314,7 @@ INIT_LOCK = Lock()
 def initialize(pause_downloader = False, clean_up = False, force_save= False, evalSched=False):
     global __INITIALIZED__, FAIL_ON_CRC, CREATE_GROUP_FOLDERS,  DO_FILE_JOIN, AUTODISCONNECT, \
            DO_UNZIP, DO_UNRAR, DO_SAVE, PAR_CLEANUP, PAR_OPTION, NO_DUPES, CLEANUP_LIST, IGNORE_SAMPLES, \
-           USERNAME_NEWZBIN, PASSWORD_NEWZBIN, API_KEY, POSTPROCESSOR, ASSEMBLER, \
+           USERNAME_NEWZBIN, PASSWORD_NEWZBIN, API_KEY, NO_API_KEY, POSTPROCESSOR, ASSEMBLER, \
            DIRSCANNER, MSGIDGRABBER, URLGRABBER, SCHED, NZBQ, DOWNLOADER, BOOKMARKS, \
            NZB_BACKUP_DIR, DOWNLOAD_DIR, DOWNLOAD_FREE, \
            LOGFILE, WEBLOGFILE, LOGHANDLER, GUIHANDLER, LOGLEVEL, AMBI_LOCALHOST, WAITEXIT, \
@@ -324,7 +326,7 @@ def initialize(pause_downloader = False, clean_up = False, force_save= False, ev
            DIR_HOME, DIR_APPDATA, DIR_LCLDATA, DIR_PROG , DIR_INTERFACES, \
            EMAIL_SERVER, EMAIL_TO, EMAIL_FROM, EMAIL_ACCOUNT, EMAIL_PWD, \
            EMAIL_ENDJOB, EMAIL_FULL, TV_SORT_STRING, ENABLE_TV_SORTING, AUTO_SORT, WEB_COLOR, WEB_COLOR2, \
-           WEB_DIR, WEB_DIR2, pause_on_post_processing, DARWIN, IONICE_ARGS
+           WEB_DIR, WEB_DIR2, pause_on_post_processing, DARWIN, IONICE_ARGS, PAR_MULTICORE
 
     if __INITIALIZED__:
         return False
@@ -342,8 +344,9 @@ def initialize(pause_downloader = False, clean_up = False, force_save= False, ev
 
     USERNAME_NEWZBIN = check_setting_str(CFG, 'newzbin', 'username', '')
     PASSWORD_NEWZBIN = decodePassword(check_setting_str(CFG, 'newzbin', 'password', '', False), 'web')
-    
+
     API_KEY = check_setting_str(CFG, 'misc', 'api_key', create_api_key())
+    NO_API_KEY = bool(check_setting_int(CFG, 'misc', 'disable_api_key', 0))
 
     VERSION_CHECK = bool(check_setting_int(CFG, 'misc', 'check_new_rel', 1))
 
@@ -365,6 +368,8 @@ def initialize(pause_downloader = False, clean_up = False, force_save= False, ev
     AUTODISCONNECT = bool(check_setting_int(CFG, 'misc', 'auto_disconnect', 1))
 
     PAR_CLEANUP = bool(check_setting_int(CFG, 'misc', 'enable_par_cleanup', 1))
+    
+    PAR_MULTICORE = bool(check_setting_int(CFG, 'misc', 'enable_par_multicore', 1))
 
     PAR_OPTION = check_setting_str(CFG, 'misc', 'par_option', '')
     if PAR_OPTION.lower() == 'none':
