@@ -51,7 +51,7 @@ from sabnzbd.misc import real_path, create_real_path, save_configfile, \
 from sabnzbd.nzbstuff import SplitFileName
 from sabnzbd.newswrapper import GetServerParms
 from sabnzbd.newzbin import InitCats, IsNewzbin
-from sabnzbd.codecs import TRANS, xml_name
+from sabnzbd.codecs import TRANS, xml_name, LatinFilter
 
 from sabnzbd.constants import *
 
@@ -61,6 +61,12 @@ PROVIDER = DictAuthProvider({})
 
 USERNAME = None
 PASSWORD = None
+DIRECTIVES = {
+           'directiveStartToken': '<!--#',
+           'directiveEndToken': '#-->',
+           'prioritizeSearchListOverSelf' : True
+           }
+FILTER = LatinFilter
 
 #------------------------------------------------------------------------------
 try:
@@ -112,7 +118,7 @@ def CheckFreeSpace():
 
 
 def check_session(key):
-    if key == sabnzbd.API_KEY:
+    if sabnzbd.NO_API_KEY or key == sabnzbd.API_KEY:
         return None
     elif not key:
         return 'error: Session Key Required'
@@ -314,8 +320,7 @@ class MainPage(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'main.tmpl'),
                             searchList=[info],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -400,7 +405,7 @@ class MainPage(ProtectedClass):
                   try_list: %s''' % sabnzbd.debug()
 
     @cherrypy.expose
-    def rss(self, mode='history'):
+    def rss(self, mode='history', session=None):
         if mode == 'history':
             return rss_history()
         elif mode == 'warnings':
@@ -423,12 +428,13 @@ class MainPage(ProtectedClass):
 
         # An API Key is required (as well as the standard user/pass if set)
         # For accessing the api and other protected areas
-        if not apikey:
-            logging.warning("[%s] API Key missing, please enter the api key from config>general "
-                            "into your 3rd party program:", __NAME__)
-            return 'error: API Key Required'
-        if sabnzbd.API_KEY != apikey:
-            return 'error: API Key Incorrect'
+        if not sabnzbd.NO_API_KEY:
+            if not apikey:
+                logging.warning("[%s] API Key missing, please enter the api key from config>general "
+                                "into your 3rd party program:", __NAME__)
+                return 'error: API Key Required'
+            if sabnzbd.API_KEY != apikey:
+                return 'error: API Key Incorrect'
 
 
         if mode == 'qstatus':
@@ -609,8 +615,7 @@ class NzoPage(ProtectedClass):
 
             template = Template(file=os.path.join(self.__web_dir, 'nzo.tmpl'),
                                 searchList=[info],
-                                compilerSettings={'directiveStartToken': '<!--#',
-                                                  'directiveEndToken': '#-->'})
+                                filter=FILTER, compilerSettings=DIRECTIVES)
             return template.respond()
         else:
             return "ERROR: %s deleted" % self.__nzo_id
@@ -802,8 +807,7 @@ class QueuePage(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'queue.tmpl'),
                             searchList=[info],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -1040,8 +1044,7 @@ class HistoryPage(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'history.tmpl'),
                             searchList=[history],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -1079,8 +1082,7 @@ class HistoryPage(ProtectedClass):
 
     @cherrypy.expose
     def scriptlog(self, name=None, dummy=None, session=None):
-        msg = check_session(session)
-        if msg: return msg
+        # Don't check session key, this will break old history links
 
         if name:
             path = os.path.dirname(sabnzbd.LOGFILE)
@@ -1130,8 +1132,7 @@ class ConfigPage(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'config.tmpl'),
                             searchList=[config],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -1181,8 +1182,7 @@ class ConfigDirectories(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'config_directories.tmpl'),
                             searchList=[config],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -1251,7 +1251,7 @@ class ConfigDirectories(ProtectedClass):
         sabnzbd.CFG['misc']['script_dir'] = script_dir
         sabnzbd.CFG['misc']['complete_dir'] = complete_dir
         sabnzbd.CFG['misc']['nzb_backup_dir'] = nzb_backup_dir
-        if permissions: sabnzbd.CFG['misc']['permissions'] = permissions
+        sabnzbd.CFG['misc']['permissions'] = permissions
         sabnzbd.CFG['misc']['enable_tv_sorting'] = IntConv(enable_tv_sorting)
         sabnzbd.CFG['misc']['tv_sort_string'] = tv_sort_string
 
@@ -1283,6 +1283,7 @@ class ConfigSwitches(ProtectedClass):
         config['enable_filejoin'] = IntConv(sabnzbd.CFG['misc']['enable_filejoin'])
         #config['enable_save'] = IntConv(sabnzbd.CFG['misc']['enable_save'])
         config['enable_par_cleanup'] = IntConv(sabnzbd.CFG['misc']['enable_par_cleanup'])
+        config['enable_par_multicore'] = IntConv(sabnzbd.CFG['misc']['enable_par_multicore'])
         config['send_group'] = IntConv(sabnzbd.CFG['misc']['send_group'])
         config['fail_on_crc'] = IntConv(sabnzbd.CFG['misc']['fail_on_crc'])
         #config['create_group_folders'] = IntConv(sabnzbd.CFG['misc']['create_group_folders'])
@@ -1306,8 +1307,7 @@ class ConfigSwitches(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'config_switches.tmpl'),
                             searchList=[config],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -1326,9 +1326,8 @@ class ConfigSwitches(ProtectedClass):
                      ignore_samples = None,
                      pause_on_post_processing = None,
                      script = None,
-                     ionice=None,
-                     dummy=None,
-                     session = None
+                     ionice=None, dummy=None, session = None,
+                     enable_par_multicore=None
                      ):
         msg = check_session(session)
         if msg: return msg
@@ -1341,6 +1340,10 @@ class ConfigSwitches(ProtectedClass):
             sabnzbd.CFG['misc']['ionice'] = ionice
         else:
             sabnzbd.CFG['misc']['ionice'] = ""
+        if enable_par_multicore:
+            sabnzbd.CFG['misc']['enable_par_multicore'] = IntConv(enable_par_multicore)
+        else:
+            sabnzbd.CFG['misc']['enable_par_multicore'] = 0
 
         sabnzbd.CFG['misc']['enable_unrar'] = IntConv(enable_unrar)
         sabnzbd.CFG['misc']['enable_unzip'] = IntConv(enable_unzip)
@@ -1406,6 +1409,7 @@ class ConfigGeneral(ProtectedClass):
         config['refresh_rate'] = sabnzbd.CFG['misc']['refresh_rate']
         config['rss_rate'] = sabnzbd.CFG['misc']['rss_rate']
         config['cache_limitstr'] = sabnzbd.CFG['misc']['cache_limit'].upper()
+        config['disable_key'] = sabnzbd.NO_API_KEY
 
         wlist = [DEF_STDINTF]
         wlist2 = ['None', DEF_STDINTF]
@@ -1432,14 +1436,13 @@ class ConfigGeneral(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'config_general.tmpl'),
                             searchList=[config],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
     def saveGeneral(self, host = None, port = None, web_username = None, web_password = None, web_dir = None,
                     web_dir2 = None, web_color = None,
-                    cronlines = None, refresh_rate = None, rss_rate = None,
+                    cronlines = None, refresh_rate = None, rss_rate = None, disable_key=None,
                     bandwith_limit = None, cleanup_list = None, cache_limitstr = None, dummy=None, session=None):
         msg = check_session(session)
         if msg: return msg
@@ -1466,6 +1469,7 @@ class ConfigGeneral(ProtectedClass):
         sabnzbd.CFG['misc']['rss_rate'] = sabnzbd.minimax(rss_rate, 15, 24*60)
         sabnzbd.CFG['misc']['cleanup_list'] = listquote.simplelist(cleanup_list)
         sabnzbd.CFG['misc']['cache_limit'] = cache_limitstr
+        sabnzbd.CFG['misc']['disable_api_key'] = disable_key
 
         return saveAndRestart(self.__root, dummy)
 
@@ -1517,8 +1521,7 @@ class ConfigServer(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'config_server.tmpl'),
                             searchList=[config],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -1711,8 +1714,7 @@ class ConfigRss(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'config_rss.tmpl'),
                             searchList=[config],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -1896,8 +1898,7 @@ class ConfigScheduling(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'config_scheduling.tmpl'),
                             searchList=[config],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -1952,8 +1953,7 @@ class ConfigNewzbin(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'config_newzbin.tmpl'),
                             searchList=[config],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -2049,8 +2049,7 @@ class ConfigCats(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'config_cat.tmpl'),
                             searchList=[config],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -2177,8 +2176,7 @@ class ConnectionInfo(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'connection_info.tmpl'),
                             searchList=[header],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -2353,8 +2351,8 @@ def ShowRssLog(feed, all):
                 script = '&script=' + escape(job[5])
             else:
                 script = ''
-            badStr += '<a href="rss_download?feed=%s&id=%s%s%s">Download</a>&nbsp;&nbsp;&nbsp;%s<br/>' % \
-                (qfeed, name, cat, pp, xml_name(job[1]))
+            badStr += '<a href="rss_download?session=%s&feed=%s&id=%s%s%s">Download</a>&nbsp;&nbsp;&nbsp;%s<br/>' % \
+                (sabnzbd.API_KEY, qfeed, name, cat, pp, xml_name(job[1]))
 
     if all:
         return '''
@@ -2553,8 +2551,7 @@ class ConfigEmail(ProtectedClass):
 
         template = Template(file=os.path.join(self.__web_dir, 'config_email.tmpl'),
                             searchList=[config],
-                            compilerSettings={'directiveStartToken': '<!--#',
-                                              'directiveEndToken': '#-->'})
+                            filter=FILTER, compilerSettings=DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
@@ -2755,6 +2752,7 @@ def xml_qstatus():
                 <mbleft>%(mbleft)s</mbleft> \n\
                 <mb>%(mb)s</mb> \n\
                 <noofslots>%(noofslots)s</noofslots> \n\
+                <have_warnings>%(have_warnings)s</have_warnings> \n\
                 <diskspace1>%(diskspace1)s</diskspace1> \n\
                 <diskspace2>%(diskspace2)s</diskspace2> \n\
                 <timeleft>%(timeleft)s</timeleft> \n' % status
