@@ -1171,11 +1171,11 @@ def BadFetch(nzo, url):
     else:
         nzo.set_filename('Failed to fetch NZB from %s' % url)
 
-    nzo.set_unpackstr('=> Failed, <a href="./retry?url=%s%s%s%s">Try again</a>' % \
-                     (urllib.quote(url), pp, urllib.quote(cat), urllib.quote(script)),
+    nzo.set_unpackstr('=> Failed, <a href="./retry?session=%s&url=%s%s%s%s">Try again</a>' % \
+                     (sabnzbd.API_KEY, urllib.quote(url), pp, urllib.quote(cat), urllib.quote(script)),
                      '[URL Fetch]', 0)
     sabnzbd.remove_nzo(nzo.nzo_id, add_to_history=True, unload=True)
-    
+
 def create_api_key():
     try:
         from hashlib import md5
@@ -1189,6 +1189,6 @@ def create_api_key():
     m = md5(t)
     # Update the md5 instance with the random variable
     m.update(r)
-    
+
     # Return a hex digest of the md5, eg 49f68a5c8493ec2c0bf489821c21fc3b
     return m.hexdigest()
