@@ -64,18 +64,12 @@ def find_programs(curdir):
     """Find external programs
     """
     if sabnzbd.DARWIN:
-       p = os.path.abspath(curdir + '/osx/par2/par2')
-       if os.access(p, os.X_OK):
-           sabnzbd.newsunpack.PAR2_COMMAND = p
-       p = os.path.abspath(curdir + '/osx/par2/par2-classic')
-       if os.access(p, os.X_OK):
-           sabnzbd.newsunpack.PAR2C_COMMAND = p
-       p = os.path.abspath(curdir + '/osx/unrar/unrar')
-       if os.access(p, os.X_OK):
-           sabnzbd.newsunpack.RAR_COMMAND = p
-       import platform
-       if platform.machine() != 'i386':
-           sabnzbd.newsunpack.PAR2_COMMAND = sabnzbd.newsunpack.PAR2C_COMMAND
+        p = os.path.abspath(curdir + '/osx/par2/par2-classic')
+        if os.access(p, os.X_OK):
+            sabnzbd.newsunpack.PAR2_COMMAND = p
+        p = os.path.abspath(curdir + '/osx/unrar/unrar')
+        if os.access(p, os.X_OK):
+            sabnzbd.newsunpack.RAR_COMMAND = p
 
     if os.name == 'nt':
         p = os.path.abspath(curdir + '/win/par2/par2.exe')
@@ -230,12 +224,12 @@ def unpack_magic(nzo, workdir, workdir_complete, dele, joinables, zips, rars):
             logging.info('[%s] Unzip finished on %s', __NAME__, workdir)
 
     if rerun:
-            z, y = unpack_magic(nzo, workdir, workdir_complete, dele, xjoinables,
-                             xzips, xrars)
-            if z:
-                error = z
-            if y:
-                newfiles.extend(y)
+        z, y = unpack_magic(nzo, workdir, workdir_complete, dele, xjoinables,
+                            xzips, xrars)
+        if z:
+            error = z
+        if y:
+            newfiles.extend(y)
 
     return error, newfiles
 
@@ -328,8 +322,8 @@ def file_join(nzo, workdir, workdir_complete, delete, joinables):
         msg = sys.exc_info()[1]
         nzo.set_unpackstr('=> Error "%s" while running file_join' % msg, actionname, 4)
         logging.error('[%s] Error "%s" while' + \
-                          ' running file_join on %s',
-                          __NAME__, msg, nzo.get_filename())
+                      ' running file_join on %s',
+                      __NAME__, msg, nzo.get_filename())
         return True
 
     return False
@@ -410,8 +404,8 @@ def rar_unpack(nzo, workdir, workdir_complete, delete, rars):
         msg = sys.exc_info()[1]
         nzo.set_unpackstr('=> Error "%s" while running rar_unpack' % msg, actionname, 2)
         logging.error('[%s] Error "%s" while' + \
-                          ' running rar_unpack on %s',
-                          __NAME__, msg, nzo.get_filename())
+                      ' running rar_unpack on %s',
+                      __NAME__, msg, nzo.get_filename())
         return True, ''
 
 def RAR_Extract(rarfile, numrars, nzo, actionname, extraction_path):
@@ -474,7 +468,7 @@ def RAR_Extract(rarfile, numrars, nzo, actionname, extraction_path):
             nzo.set_unpackstr('=> ERROR: unable to find "%s"' % filename,
                               actionname, 2)
             logging.warning('[%s] ERROR: unable to find "%s"', __NAME__,
-                                                                       filename)
+                            filename)
             fail = 1
 
         elif line.endswith('- CRC failed'):
@@ -502,7 +496,7 @@ def RAR_Extract(rarfile, numrars, nzo, actionname, extraction_path):
                 '=> ERROR: CRC failed in "%s" - password incorrect?' % filename,
                 actionname, 2)
             logging.warning('[%s] ERROR: encrypted file: "%s"', __NAME__,
-                                                                       filename)
+                            filename)
             fail = 1
 
         else:
@@ -574,7 +568,7 @@ def unzip(nzo, workdir, workdir_complete, delete, zips):
                 i += 1
 
         nzo.set_unpackstr("=> Unzipped %d file(s) in %1.fs" % (i, time() - tms),
-                                                                  actionname, 3)
+                          actionname, 3)
 
         # Delete the old files if we have to
         if delete and not unzip_failed:
@@ -606,8 +600,8 @@ def unzip(nzo, workdir, workdir_complete, delete, zips):
         msg = sys.exc_info()[1]
         nzo.set_unpackstr('=> Error "%s" while running unzip()' % msg, actionname, 3)
         logging.error('[%s] Error "%s" while' + \
-                          ' running unzip() on %s',
-                          __NAME__, msg, nzo.get_filename())
+                      ' running unzip() on %s',
+                      __NAME__, msg, nzo.get_filename())
         return True
 
 def ZIP_Extract(zipfile, extraction_path):
@@ -646,7 +640,7 @@ def par2_repair(parfile_nzf, nzo, workdir, setname):
         old_dir_content = os.listdir(workdir)
 
         finished, readd, pars, datafiles = PAR_Verify(parfile, parfile_nzf, nzo,
-                                                       actionname, joinables)
+                                                      actionname, joinables)
 
         if finished:
             result = True
@@ -720,8 +714,8 @@ def par2_repair(parfile_nzf, nzo, workdir, setname):
         msg = sys.exc_info()[1]
         nzo.set_unpackstr('=> Error "%s" while running par2_repair' % msg, actionname, 1)
         logging.error('[%s] Error "%s" while' + \
-                          ' running par2_repair on set %s',
-                           __NAME__, msg, setname)
+                      ' running par2_repair on set %s',
+                      __NAME__, msg, setname)
 
     return readd, result
 
@@ -733,13 +727,20 @@ def PAR_Verify(parfile, parfile_nzf, nzo, actionname, joinables):
     start = time()
 
     odd = OddFiles(parfile)
-
-    if sabnzbd.PAR_OPTION and not (odd and PAR2C_COMMAND):
-        command = [str(PAR2_COMMAND), 'r', str(sabnzbd.PAR_OPTION.strip()), parfile]
-    elif odd and PAR2C_COMMAND:
+    
+    if not sabnzbd.PAR_MULTICORE and PAR2C_COMMAND:
+        # If multicore is disabled, force classic par2.exe
         command = [str(PAR2C_COMMAND), 'r', parfile]
     else:
-        command = [str(PAR2_COMMAND), 'r', parfile]
+        # Else decide which to use
+        if sabnzbd.PAR_OPTION and not (odd and PAR2C_COMMAND):
+            command = [str(PAR2_COMMAND), 'r', str(sabnzbd.PAR_OPTION.strip()), parfile]
+        elif odd and PAR2C_COMMAND:
+            command = [str(PAR2C_COMMAND), 'r', parfile]
+        else:
+            command = [str(PAR2_COMMAND), 'r', parfile]
+
+
 
     for joinable in joinables:
         command.append(joinable)
@@ -798,7 +799,7 @@ def PAR_Verify(parfile, parfile_nzf, nzo, actionname, joinables):
             nzo.set_unpackstr('=> Verified in %.1fs, repair is required' % \
                               (time() - start), actionname, 1)
             logging.info('[%s] Verified in %.1fs, repair is required', __NAME__,
-                          time() - start)
+                         time() - start)
             start = time()
             verified = 1
 
@@ -861,8 +862,8 @@ def PAR_Verify(parfile, parfile_nzf, nzo, actionname, joinables):
                 # Tell SAB that we always have enough blocks, so that
                 # it will try to load all pars anyway
                 nzo.set_unpackstr(\
-                     '=> Not enough repair blocks, downloading all available (%d short)' % \
-                     int(needed_blocks - avail_blocks), actionname, 1)
+                    '=> Not enough repair blocks, downloading all available (%d short)' % \
+                    int(needed_blocks - avail_blocks), actionname, 1)
                 nzo.set_status("Failed")
                 needed_blocks = avail_blocks
                 force = True
@@ -892,8 +893,8 @@ def PAR_Verify(parfile, parfile_nzf, nzo, actionname, joinables):
 
             else:
                 nzo.set_unpackstr(\
-                     '=> Not enough repair blocks left (have: %s, need: %s)' % \
-                     (avail_blocks, needed_blocks), actionname, 1)
+                    '=> Not enough repair blocks left (have: %s, need: %s)' % \
+                    (avail_blocks, needed_blocks), actionname, 1)
                 nzo.set_status("Failed")
 
         elif line.startswith('Repair is possible'):
@@ -937,7 +938,7 @@ def PAR_Verify(parfile, parfile_nzf, nzo, actionname, joinables):
                 if verifytotal == 0 or verifynum < verifytotal:
                     verifynum += 1
                     nzo.set_unpackstr('=> Verifying : %02d/%02d' % \
-                               (verifynum, verifytotal), actionname, 1)
+                                      (verifynum, verifytotal), actionname, 1)
                     nzo.set_status("Verifying...")
                 datafiles.append(m.group(1))
                 continue
